//--------------------------------------------------------------------------------------------
// JavaScript Routines for all MC Ultra TrackInfo Plugins for JRiver Media Center V32 & higher
// -------------------------------------------------------------------------------------------
// Copyright (C) 2024 JRiver & EnglishTiger All Rights Reserved.
// Author: 		EnglishTiger
// Email:  		EnglishTiger@outlook.com
// File Name: mc_javascript.js
// Version: 	1.1.0
// Changes:-
// functions switchBti() + switchTai() modified to switch from using "Classical" to identify a Western Classical Music Track
// To using the Western Classical Music Eras/Periods; Medieval, Renaissance, Baroque, Classical, Romantic, Modernist, Postmodernist and Contemporary
// -------------------------------------------------------------------------------------------
//
// matchSkin uses the List Back and Text Colours from the Current Skin  to Customise the TrackInfo Plugin 
// The 1st 2 sections load the Hex Values for the Skin's Back and Text Colours
// The 3rd section builds the CSS code/instructions used to carry out the customisation:-
// s1 customises the body section of mc_ultra_layout.css
// s2 customises the DropDown Menu Entries in normal mode where the back and text colours are those from the skin
// s3 customises the DropDown Menu Entries when the user hovers over them by swapping the back and text colours
// s4 & s5 customise the Horizontal Scrollbar Tracks and Thumbs
// s6 & s7 customise the Vertical Scrollbar Tracks and Thumbs
// 
// The final section creates the style section in the head section of index.html, merges s1, s2, s3, s4, s5, s6. s7 into a single entity and then writes it to index.html
//
	function matchSkin() {
		var b1 = document.getElementById("backcol").innerText;
		var t1 = document.getElementById("textcol").innerText;		
		
		var s1 = "body {background: #" + b1 + "; color: #" + t1 + ";}";
		var s2 = ".c1-menu-btn, .c1-menu-entry a {background: #" + b1 + "; color: #" + t1 + ";}";
		var s3 = ".c1-menu-btn:hover, .c1-menu-entry a:hover {background: #" + t1 + "; color: #" + b1 + ";}";
		var s4 = "::-webkit-scrollbar-track-piece:horizontal {background: #" + b1 + "; -webkit-box-shadow: inset 0 0 6px #" + t1 + ";}";
		var s5 = "::-webkit-scrollbar-thumb:horizontal {background: #" + t1 + "; -webkit-box-shadow: inset 0 0 6px #" + b1 + ";}";
		var s6 = "::-webkit-scrollbar-track-piece:vertical {background: #" + t1 + "; -webkit-box-shadow: inset 0 0 6px #" + b1 + ";}";
		var s7 = "::-webkit-scrollbar-thumb:vertical {background: #" + b1 + "; -webkit-box-shadow: inset 0 0 6px #" + t1 + ";}";
		
    var style = document.createElement("style");
    style.innerText = s1 + s2 + s3 + s4 + s5 + s6 + s7;
    document.head.appendChild(style);
	}
// -------------------------------------------------------------------------------------------
// MC ;delimited lists are not very readable as there is no space between the ; and the next element/item
// listEdit uses global replace to add a space between the ; and the next element/item
//
	function listEdit() {
		var x = document.getElementsByName("mod");
		var i;
		for (i = 0; i < x.length; i++) {
			var str = x[i].innerHTML;
			if (str == "") { //Empty/Unused Tag/Field
				continue;
			}
			else if (str.indexOf(";") == -1) { // List only contains 1 entry/element (no ; in the data)
				continue;
			}
		else {
			x[i].innerHTML = str.replace(/;/g, "; "); // List contains multiple entries so add a space behind each ;
			}
		}
	}
// -------------------------------------------------------------------------------------------
// MC Channel No.s are just numbers that indicate the total number of channels
// chExpand extends the info displayed by adding relevant channel layout info
// i.e 3 = 2.1, 6 = 5.1, 8 = 7.1
// chExpand translates them by adding relevant info
//
	function chExpand() {
		var c = document.getElementById("expand").innerHTML;
		var res = null;
		switch (c) {
			case "1":
				res = c + " (Mono)";
				break;
			case "2":
				res = c + " (Stereo)";
				break;
			case "3":
				res = c + " (2.1)";
				break;
			case "4":
				res = c + " (Quadrophonic)";
				break;
			case "5":
				res = c + " (Surround)";
				break;
			case "6":
				res = c + " (5.1 Surround)";
				break;
			case "7":
				res = c + " (Surround)";
				break;
			case "8":
				res = c +  " (7.1 Theatre Surround)";
				break
			default:
				res = c;
		}
		document.getElementById("expand").innerHTML = res;
	}
// -------------------------------------------------------------------------------------------
// Routine used to switch between Western Classical and Non-Classical Basic Track Info Display Mode
// It does this by looking for the presence, or absence, of the Name of a Western Classical Music Type/Era in the Hidden Genre Tag
// Where Medieval, Renaissance, Baroque, Classical, Romantic, Modernist, Postmodernist, Contemporary indicates a Western Classical Music Track and any other value indicates a Non-Classical Track
// to reveal (display) the relevant parts of the sections of the html file
//
	function switchBti() {
		var c = document.getElementById("classic").innerHTML;
		switch (c) {
			case "Medieval":
			case "Renaissance":
			case "Baroque":
			case "Classical":
			case "Romantic":
			case "Modernist":
			case "Postmodernist":
			case "Contemporary":
				document.getElementById("class1").style.display = "block";
				break;
			default:
				document.getElementById("pop1").style.display = "block";
		}
	}
// ---------------------------------------------------------------------------------------------------
// Routine used to switch between Western Classical and Non-Classical Display Mode on the Track + Album Info Page
// It does this by looking for the presence, or absence, of the Name of a Western Classical Music Type/Era in the Hidden Genre Tag
// Where Medieval, Renaissance, Baroque, Classical, Romantic, Modernist, Postmodernist, Contemporary indicates a Western Classical Music Track and any other value indicates a Non-Classical Track
// to reveal (display) the relevant parts of the sections of the html file
//
	function switchTai() {
		var c = document.getElementById("classic").innerHTML;
		switch (c) {
			case "Medieval":
			case "Renaissance":
			case "Baroque":
			case "Classical":
			case "Romantic":
			case "Modernist":
			case "Postmodernist":
			case "Contemporary":
				document.getElementById("c2tac").style.display = "block";
				break;
			default:
				document.getElementById("c2tap").style.display = "block";
		}
	}
// -------------------------------------------------------------------------------------------
